@@ -7,17 +7,17 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "kwin_wayland_test.h"
-#include "abstract_client.h"
+
 #include "platform.h"
 #include "virtualdesktops.h"
+#include "wayland/display.h"
+#include "wayland/idle_interface.h"
 #include "wayland_server.h"
+#include "window.h"
 #include "workspace.h"
 
 #include <KWayland/Client/surface.h>
 
-#include <KWaylandServer/display.h>
-#include <KWaylandServer/idle_interface.h>
-
 using namespace KWin;
 using namespace KWayland::Client;
 using KWaylandServer::IdleInterface;
@@ -41,7 +41,7 @@ private Q_SLOTS:
 
 void TestIdleInhibition::initTestCase()
 {
-    qRegisterMetaType<KWin::AbstractClient*>();
+    qRegisterMetaType<KWin::Window *>();
 
     QSignalSpy applicationStartedSpy(kwinApp(), &Application::started);
     QVERIFY(applicationStartedSpy.isValid());
@@ -57,7 +57,6 @@ void TestIdleInhibition::initTestCase()
 void TestIdleInhibition::init()
 {
     QVERIFY(Test::setupWaylandConnection(Test::AdditionalWaylandInterface::IdleInhibitV1));
-
 }
 
 void TestIdleInhibition::cleanup()
@@ -70,7 +69,7 @@ void TestIdleInhibition::cleanup()
 
 void TestIdleInhibition::testInhibit()
 {
-    auto idle = waylandServer()->display()->findChild<IdleInterface*>();
+    auto idle = waylandServer()->display()->findChild<IdleInterface *>();
     QVERIFY(idle);
     QVERIFY(!idle->isInhibited());
     QSignalSpy inhibitedSpy(idle, &IdleInterface::inhibitedChanged);
@@ -84,9 +83,9 @@ void TestIdleInhibition::testInhibit()
     QScopedPointer<Test::IdleInhibitorV1> inhibitor(Test::createIdleInhibitorV1(surface.data()));
     QVERIFY(inhibitor);
 
-    // render the client
-    auto c = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
-    QVERIFY(c);
+    // render the window
+    auto window = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+    QVERIFY(window);
 
     // this should inhibit our server object
     QVERIFY(idle->isInhibited());
@@ -102,7 +101,7 @@ void TestIdleInhibition::testInhibit()
     QVERIFY(idle->isInhibited());
 
     shellSurface.reset();
-    QVERIFY(Test::waitForWindowDestroyed(c));
+    QVERIFY(Test::waitForWindowDestroyed(window));
     QTRY_VERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 4);
 }
@@ -122,7 +121,7 @@ void TestIdleInhibition::testDontInhibitWhenNotOnCurrentDesktop()
     QSignalSpy inhibitedSpy(idle, &IdleInterface::inhibitedChanged);
     QVERIFY(inhibitedSpy.isValid());
 
-    // Create the test client.
+    // Create the test window.
     QScopedPointer<KWayland::Client::Surface> surface(Test::createSurface());
     QVERIFY(!surface.isNull());
     QScopedPointer<Test::XdgToplevel> shellSurface(Test::createXdgToplevelSurface(surface.data()));
@@ -132,13 +131,13 @@ void TestIdleInhibition::testDontInhibitWhenNotOnCurrentDesktop()
     QScopedPointer<Test::IdleInhibitorV1> inhibitor(Test::createIdleInhibitorV1(surface.data()));
     QVERIFY(inhibitor);
 
-    // Render the client.
-    auto c = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
-    QVERIFY(c);
+    // Render the window.
+    auto window = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+    QVERIFY(window);
 
-    // The test client should be only on the first virtual desktop.
-    QCOMPARE(c->desktops().count(), 1);
-    QCOMPARE(c->desktops().first(), VirtualDesktopManager::self()->desktops().first());
+    // The test window should be only on the first virtual desktop.
+    QCOMPARE(window->desktops().count(), 1);
+    QCOMPARE(window->desktops().first(), VirtualDesktopManager::self()->desktops().first());
 
     // This should inhibit our server object.
     QVERIFY(idle->isInhibited());
@@ -155,14 +154,14 @@ void TestIdleInhibition::testDontInhibitWhenNotOnCurrentDesktop()
     // Switch back to the first virtual desktop.
     VirtualDesktopManager::self()->setCurrent(1);
 
-    // The test client became visible again, so the compositor has to honor the idle
+    // The test window became visible again, so the compositor has to honor the idle
     // inhibitor object back again.
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 3);
 
-    // Destroy the test client.
+    // Destroy the test window.
     shellSurface.reset();
-    QVERIFY(Test::waitForWindowDestroyed(c));
+    QVERIFY(Test::waitForWindowDestroyed(window));
     QTRY_VERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 4);
 }
@@ -172,14 +171,14 @@ void TestIdleInhibition::testDontInhibitWhenMinimized()
     // This test verifies that the idle inhibitor object is not honored when the
     // associated surface is minimized.
 
-     // Get reference to the idle interface.
+    // Get reference to the idle interface.
     auto idle = waylandServer()->display()->findChild<IdleInterface *>();
     QVERIFY(idle);
     QVERIFY(!idle->isInhibited());
     QSignalSpy inhibitedSpy(idle, &IdleInterface::inhibitedChanged);
     QVERIFY(inhibitedSpy.isValid());
 
-    // Create the test client.
+    // Create the test window.
     QScopedPointer<KWayland::Client::Surface> surface(Test::createSurface());
     QVERIFY(!surface.isNull());
     QScopedPointer<Test::XdgToplevel> shellSurface(Test::createXdgToplevelSurface(surface.data()));
@@ -189,27 +188,27 @@ void TestIdleInhibition::testDontInhibitWhenMinimized()
     QScopedPointer<Test::IdleInhibitorV1> inhibitor(Test::createIdleInhibitorV1(surface.data()));
     QVERIFY(inhibitor);
 
-    // Render the client.
-    auto c = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
-    QVERIFY(c);
+    // Render the window.
+    auto window = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+    QVERIFY(window);
 
     // This should inhibit our server object.
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 1);
 
-    // Minimize the client, the idle inhibitor object should not be honored.
-    c->minimize();
+    // Minimize the window, the idle inhibitor object should not be honored.
+    window->minimize();
     QVERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 2);
 
-    // Unminimize the client, the idle inhibitor object should be honored back again.
-    c->unminimize();
+    // Unminimize the window, the idle inhibitor object should be honored back again.
+    window->unminimize();
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 3);
 
-    // Destroy the test client.
+    // Destroy the test window.
     shellSurface.reset();
-    QVERIFY(Test::waitForWindowDestroyed(c));
+    QVERIFY(Test::waitForWindowDestroyed(window));
     QTRY_VERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 4);
 }
@@ -217,7 +216,7 @@ void TestIdleInhibition::testDontInhibitWhenMinimized()
 void TestIdleInhibition::testDontInhibitWhenUnmapped()
 {
     // This test verifies that the idle inhibitor object is not honored by KWin
-    // when the associated client is unmapped.
+    // when the associated window is unmapped.
 
     // Get reference to the idle interface.
     auto idle = waylandServer()->display()->findChild<IdleInterface *>();
@@ -226,7 +225,7 @@ void TestIdleInhibition::testDontInhibitWhenUnmapped()
     QSignalSpy inhibitedSpy(idle, &IdleInterface::inhibitedChanged);
     QVERIFY(inhibitedSpy.isValid());
 
-    // Create the test client.
+    // Create the test window.
     QScopedPointer<KWayland::Client::Surface> surface(Test::createSurface());
     QVERIFY(!surface.isNull());
     QScopedPointer<Test::XdgToplevel> shellSurface(Test::createXdgToplevelSurface(surface.data()));
@@ -238,16 +237,16 @@ void TestIdleInhibition::testDontInhibitWhenUnmapped()
     QScopedPointer<Test::IdleInhibitorV1> inhibitor(Test::createIdleInhibitorV1(surface.data()));
     QVERIFY(inhibitor);
 
-    // Map the client.
-    QSignalSpy clientAddedSpy(workspace(), &Workspace::clientAdded);
-    QVERIFY(clientAddedSpy.isValid());
+    // Map the window.
+    QSignalSpy windowAddedSpy(workspace(), &Workspace::windowAdded);
+    QVERIFY(windowAddedSpy.isValid());
     Test::render(surface.data(), QSize(100, 50), Qt::blue);
-    QVERIFY(clientAddedSpy.isEmpty());
-    QVERIFY(clientAddedSpy.wait());
-    QCOMPARE(clientAddedSpy.count(), 1);
-    AbstractClient *client = clientAddedSpy.last().first().value<AbstractClient *>();
-    QVERIFY(client);
-    QCOMPARE(client->readyForPainting(), true);
+    QVERIFY(windowAddedSpy.isEmpty());
+    QVERIFY(windowAddedSpy.wait());
+    QCOMPARE(windowAddedSpy.count(), 1);
+    Window *window = windowAddedSpy.last().first().value<Window *>();
+    QVERIFY(window);
+    QCOMPARE(window->readyForPainting(), true);
 
     // The compositor will respond with a configure event when the surface becomes active.
     QVERIFY(surfaceConfigureRequestedSpy.wait());
@@ -257,10 +256,10 @@ void TestIdleInhibition::testDontInhibitWhenUnmapped()
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 1);
 
-    // Unmap the client.
+    // Unmap the window.
     surface->attachBuffer(Buffer::Ptr());
     surface->commit(KWayland::Client::Surface::CommitFlag::None);
-    QVERIFY(Test::waitForWindowDestroyed(client));
+    QVERIFY(Test::waitForWindowDestroyed(window));
 
     // The surface is no longer visible, so the compositor doesn't have to honor the
     // idle inhibitor object.
@@ -274,22 +273,22 @@ void TestIdleInhibition::testDontInhibitWhenUnmapped()
     QVERIFY(surfaceConfigureRequestedSpy.wait());
     QCOMPARE(surfaceConfigureRequestedSpy.count(), 2);
 
-    // Map the client.
+    // Map the window.
     Test::render(surface.data(), QSize(100, 50), Qt::blue);
-    QVERIFY(clientAddedSpy.wait());
-    QCOMPARE(clientAddedSpy.count(), 2);
-    client = clientAddedSpy.last().first().value<AbstractClient *>();
-    QVERIFY(client);
-    QCOMPARE(client->readyForPainting(), true);
+    QVERIFY(windowAddedSpy.wait());
+    QCOMPARE(windowAddedSpy.count(), 2);
+    window = windowAddedSpy.last().first().value<Window *>();
+    QVERIFY(window);
+    QCOMPARE(window->readyForPainting(), true);
 
-    // The test client became visible again, so the compositor has to honor the idle
+    // The test window became visible again, so the compositor has to honor the idle
     // inhibitor object back again.
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 3);
 
-    // Destroy the test client.
+    // Destroy the test window.
     shellSurface.reset();
-    QVERIFY(Test::waitForWindowDestroyed(client));
+    QVERIFY(Test::waitForWindowDestroyed(window));
     QTRY_VERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 4);
 }
@@ -309,7 +308,7 @@ void TestIdleInhibition::testDontInhibitWhenLeftCurrentDesktop()
     QSignalSpy inhibitedSpy(idle, &IdleInterface::inhibitedChanged);
     QVERIFY(inhibitedSpy.isValid());
 
-    // Create the test client.
+    // Create the test window.
     QScopedPointer<KWayland::Client::Surface> surface(Test::createSurface());
     QVERIFY(!surface.isNull());
     QScopedPointer<Test::XdgToplevel> shellSurface(Test::createXdgToplevelSurface(surface.data()));
@@ -319,37 +318,37 @@ void TestIdleInhibition::testDontInhibitWhenLeftCurrentDesktop()
     QScopedPointer<Test::IdleInhibitorV1> inhibitor(Test::createIdleInhibitorV1(surface.data()));
     QVERIFY(inhibitor);
 
-    // Render the client.
-    auto c = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
-    QVERIFY(c);
+    // Render the window.
+    auto window = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+    QVERIFY(window);
 
-    // The test client should be only on the first virtual desktop.
-    QCOMPARE(c->desktops().count(), 1);
-    QCOMPARE(c->desktops().first(), VirtualDesktopManager::self()->desktops().first());
+    // The test window should be only on the first virtual desktop.
+    QCOMPARE(window->desktops().count(), 1);
+    QCOMPARE(window->desktops().first(), VirtualDesktopManager::self()->desktops().first());
 
     // This should inhibit our server object.
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 1);
 
-    // Let the client enter the second virtual desktop.
-    c->enterDesktop(VirtualDesktopManager::self()->desktops().at(1));
+    // Let the window enter the second virtual desktop.
+    window->enterDesktop(VirtualDesktopManager::self()->desktops().at(1));
     QCOMPARE(inhibitedSpy.count(), 1);
 
-    // If the client leaves the first virtual desktop, then the associated idle
+    // If the window leaves the first virtual desktop, then the associated idle
     // inhibitor object should not be honored.
-    c->leaveDesktop(VirtualDesktopManager::self()->desktops().at(0));
+    window->leaveDesktop(VirtualDesktopManager::self()->desktops().at(0));
     QVERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 2);
 
-    // If the client enters the first desktop, then the associated idle inhibitor
+    // If the window enters the first desktop, then the associated idle inhibitor
     // object should be honored back again.
-    c->enterDesktop(VirtualDesktopManager::self()->desktops().at(0));
+    window->enterDesktop(VirtualDesktopManager::self()->desktops().at(0));
     QVERIFY(idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 3);
 
-    // Destroy the test client.
+    // Destroy the test window.
     shellSurface.reset();
-    QVERIFY(Test::waitForWindowDestroyed(c));
+    QVERIFY(Test::waitForWindowDestroyed(window));
     QTRY_VERIFY(!idle->isInhibited());
     QCOMPARE(inhibitedSpy.count(), 4);
 }
