@@ -7,22 +7,23 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "kwin_wayland_test.h"
+
 #include "composite.h"
-#include "effectloader.h"
-#include "x11client.h"
 #include "cursor.h"
+#include "effectloader.h"
 #include "effects.h"
 #include "platform.h"
+#include "wayland/shmclientbuffer.h"
+#include "wayland/surface_interface.h"
 #include "wayland_server.h"
 #include "workspace.h"
+#include "x11window.h"
 
 #include <KConfigGroup>
 
+#include <KWayland/Client/pointer.h>
 #include <KWayland/Client/seat.h>
 #include <KWayland/Client/surface.h>
-#include <KWayland/Client/pointer.h>
-#include <KWaylandServer/shmclientbuffer.h>
-#include <KWaylandServer/surface_interface.h>
 
 #include <QPainter>
 
@@ -34,7 +35,7 @@ static const QString s_socketName = QStringLiteral("wayland_test_kwin_scene_qpai
 
 class SceneQPainterTest : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 private Q_SLOTS:
     void initTestCase();
     void cleanup();
@@ -44,6 +45,9 @@ private Q_SLOTS:
     void testWindowScaled();
     void testCompositorRestart();
     void testX11Window();
+
+private:
+    QImage grab(Output *output);
 };
 
 void SceneQPainterTest::cleanup()
@@ -53,7 +57,7 @@ void SceneQPainterTest::cleanup()
 
 void SceneQPainterTest::initTestCase()
 {
-    qRegisterMetaType<KWin::AbstractClient*>();
+    qRegisterMetaType<KWin::Window *>();
     QSignalSpy applicationStartedSpy(kwinApp(), &Application::started);
     QVERIFY(applicationStartedSpy.isValid());
     kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -84,6 +88,17 @@ void SceneQPainterTest::initTestCase()
     QVERIFY(Compositor::self());
 }
 
+QImage SceneQPainterTest::grab(Output *output)
+{
+    QImage image;
+    QMetaObject::invokeMethod(kwinApp()->platform(),
+                              "captureOutput",
+                              Qt::DirectConnection,
+                              Q_RETURN_ARG(QImage, image),
+                              Q_ARG(Output *, output));
+    return image;
+}
+
 void SceneQPainterTest::testStartFrame()
 {
     // this test verifies that the initial rendering is correct
@@ -104,7 +119,7 @@ void SceneQPainterTest::testStartFrame()
     QVERIFY(!cursorImage.isNull());
     p.drawImage(cursor->pos() - cursor->hotspot(), cursorImage);
     const auto outputs = kwinApp()->platform()->enabledOutputs();
-    QCOMPARE(referenceImage, *scene->qpainterRenderBuffer(outputs.constFirst()));
+    QCOMPARE(referenceImage, grab(outputs.constFirst()));
 }
 
 void SceneQPainterTest::testCursorMoving()
@@ -136,7 +151,7 @@ void SceneQPainterTest::testCursorMoving()
     QVERIFY(!cursorImage.isNull());
     p.drawImage(QPoint(45, 45) - cursor->hotspot(), cursorImage);
     const auto outputs = kwinApp()->platform()->enabledOutputs();
-    QCOMPARE(referenceImage, *scene->qpainterRenderBuffer(outputs.constFirst()));
+    QCOMPARE(referenceImage, grab(outputs.constFirst()));
 }
 
 void SceneQPainterTest::testWindow()
@@ -175,13 +190,13 @@ void SceneQPainterTest::testWindow()
     QVERIFY(frameRenderedSpy.wait());
     painter.fillRect(KWin::Cursors::self()->mouse()->pos().x() - 5, KWin::Cursors::self()->mouse()->pos().y() - 5, 10, 10, Qt::red);
     const auto outputs = kwinApp()->platform()->enabledOutputs();
-    QCOMPARE(referenceImage, *scene->qpainterRenderBuffer(outputs.constFirst()));
+    QCOMPARE(referenceImage, grab(outputs.constFirst()));
     // let's move the cursor again
     KWin::Cursors::self()->mouse()->setPos(10, 10);
     QVERIFY(frameRenderedSpy.wait());
     painter.fillRect(0, 0, 200, 300, Qt::blue);
     painter.fillRect(5, 5, 10, 10, Qt::red);
-    QCOMPARE(referenceImage, *scene->qpainterRenderBuffer(outputs.constFirst()));
+    QCOMPARE(referenceImage, grab(outputs.constFirst()));
 }
 
 void SceneQPainterTest::testWindowScaled()
@@ -210,14 +225,14 @@ void SceneQPainterTest::testWindowScaled()
     // now let's map the window
     s->setScale(2);
 
-    //draw a blue square@400x600 with red rectangle@200x200 in the middle
-    const QSize size(400,600);
+    // draw a blue square@400x600 with red rectangle@200x200 in the middle
+    const QSize size(400, 600);
     QImage img(size, QImage::Format_ARGB32_Premultiplied);
     img.fill(Qt::blue);
     QPainter surfacePainter(&img);
-    surfacePainter.fillRect(200,300,200,200, Qt::red);
+    surfacePainter.fillRect(200, 300, 200, 200, Qt::red);
 
-    //add buffer
+    // add buffer
     Test::render(s.data(), img);
     QVERIFY(pointerEnteredSpy.wait());
     p->setCursor(cs.data(), QPoint(5, 5));
@@ -229,10 +244,10 @@ void SceneQPainterTest::testWindowScaled()
     QPainter painter(&referenceImage);
     painter.fillRect(0, 0, 200, 300, Qt::blue);
     painter.fillRect(100, 150, 100, 100, Qt::red);
-    painter.fillRect(5, 5, 10, 10, Qt::red); //cursor
+    painter.fillRect(5, 5, 10, 10, Qt::red); // cursor
 
     const auto outputs = kwinApp()->platform()->enabledOutputs();
-    QCOMPARE(referenceImage, *scene->qpainterRenderBuffer(outputs.constFirst()));
+    QCOMPARE(referenceImage, grab(outputs.constFirst()));
 }
 
 void SceneQPainterTest::testCompositorRestart()
@@ -277,7 +292,7 @@ void SceneQPainterTest::testCompositorRestart()
     QVERIFY(!cursorImage.isNull());
     painter.drawImage(QPoint(400, 400) - cursor->hotspot(), cursorImage);
     const auto outputs = kwinApp()->platform()->enabledOutputs();
-    QCOMPARE(referenceImage, *scene->qpainterRenderBuffer(outputs.constFirst()));
+    QCOMPARE(referenceImage, grab(outputs.constFirst()));
 }
 
 struct XcbConnectionDeleter
@@ -288,7 +303,7 @@ struct XcbConnectionDeleter
     }
 };
 
-static bool waitForXwaylandBuffer(Toplevel *window, const QSize &size)
+static bool waitForXwaylandBuffer(Window *window, const QSize &size)
 {
     // Usually, when an Xwayland surface is created, it has a buffer of size 1x1,
     // a buffer with the correct size will be committed a bit later.
@@ -321,9 +336,9 @@ void SceneQPainterTest::testX11Window()
     QScopedPointer<xcb_connection_t, XcbConnectionDeleter> c(xcb_connect(nullptr, nullptr));
     QVERIFY(!xcb_connection_has_error(c.data()));
     const QRect windowGeometry(0, 0, 100, 200);
-    xcb_window_t w = xcb_generate_id(c.data());
+    xcb_window_t windowId = xcb_generate_id(c.data());
     uint32_t value = kwinApp()->x11DefaultScreen()->white_pixel;
-    xcb_create_window(c.data(), XCB_COPY_FROM_PARENT, w, rootWindow(),
+    xcb_create_window(c.data(), XCB_COPY_FROM_PARENT, windowId, rootWindow(),
                       windowGeometry.x(),
                       windowGeometry.y(),
                       windowGeometry.width(),
@@ -333,25 +348,24 @@ void SceneQPainterTest::testX11Window()
     memset(&hints, 0, sizeof(hints));
     xcb_icccm_size_hints_set_position(&hints, 1, windowGeometry.x(), windowGeometry.y());
     xcb_icccm_size_hints_set_size(&hints, 1, windowGeometry.width(), windowGeometry.height());
-    xcb_icccm_set_wm_normal_hints(c.data(), w, &hints);
-    xcb_map_window(c.data(), w);
+    xcb_icccm_set_wm_normal_hints(c.data(), windowId, &hints);
+    xcb_map_window(c.data(), windowId);
     xcb_flush(c.data());
 
-
-    // we should get a client for it
-    QSignalSpy windowCreatedSpy(workspace(), &Workspace::clientAdded);
+    // we should get a window for it
+    QSignalSpy windowCreatedSpy(workspace(), &Workspace::windowAdded);
     QVERIFY(windowCreatedSpy.isValid());
     QVERIFY(windowCreatedSpy.wait());
-    X11Client *client = windowCreatedSpy.first().first().value<X11Client *>();
-    QVERIFY(client);
-    QCOMPARE(client->window(), w);
-    QCOMPARE(client->clientSize(), QSize(100, 200));
-    QVERIFY(Test::waitForWaylandSurface(client));
-    QVERIFY(waitForXwaylandBuffer(client, client->size()));
-    QImage compareImage(client->clientSize(), QImage::Format_RGB32);
+    X11Window *window = windowCreatedSpy.first().first().value<X11Window *>();
+    QVERIFY(window);
+    QCOMPARE(window->window(), windowId);
+    QCOMPARE(window->clientSize(), QSize(100, 200));
+    QVERIFY(Test::waitForWaylandSurface(window));
+    QVERIFY(waitForXwaylandBuffer(window, window->size()));
+    QImage compareImage(window->clientSize(), QImage::Format_RGB32);
     compareImage.fill(Qt::white);
-    auto buffer = qobject_cast<KWaylandServer::ShmClientBuffer *>(client->surface()->buffer());
-    QCOMPARE(buffer->data().copy(QRect(client->clientPos(), client->clientSize())), compareImage);
+    auto buffer = qobject_cast<KWaylandServer::ShmClientBuffer *>(window->surface()->buffer());
+    QCOMPARE(buffer->data().copy(QRect(window->clientPos(), window->clientSize())), compareImage);
 
     // enough time for rendering the window
     QTest::qWait(100);
@@ -365,18 +379,18 @@ void SceneQPainterTest::testX11Window()
     QVERIFY(frameRenderedSpy.isValid());
     QVERIFY(frameRenderedSpy.wait());
 
-    const QPoint startPos = client->pos() + client->clientPos();
-    auto image = scene->qpainterRenderBuffer(kwinApp()->platform()->enabledOutputs().constFirst());
-    QCOMPARE(image->copy(QRect(startPos, client->clientSize())), compareImage);
+    const QPoint startPos = window->pos() + window->clientPos();
+    auto image = grab(kwinApp()->platform()->enabledOutputs().constFirst());
+    QCOMPARE(image.copy(QRect(startPos, window->clientSize())), compareImage);
 
     // and destroy the window again
-    xcb_unmap_window(c.data(), w);
+    xcb_unmap_window(c.data(), windowId);
     xcb_flush(c.data());
 
-    QSignalSpy windowClosedSpy(client, &X11Client::windowClosed);
+    QSignalSpy windowClosedSpy(window, &X11Window::windowClosed);
     QVERIFY(windowClosedSpy.isValid());
     QVERIFY(windowClosedSpy.wait());
-    xcb_destroy_window(c.data(), w);
+    xcb_destroy_window(c.data(), windowId);
     c.reset();
 }
 
