@@ -30,7 +30,7 @@ class EglGbmLayer : public DrmPipelineLayer
 public:
     EglGbmLayer(EglGbmBackend *eglBackend, DrmPipeline *pipeline);
 
-    OutputLayerBeginFrameInfo beginFrame() override;
+    std::optional<OutputLayerBeginFrameInfo> beginFrame() override;
     void aboutToStartPainting(const QRegion &damagedRegion) override;
     bool endFrame(const QRegion &renderedRegion, const QRegion &damagedRegion) override;
     bool scanout(SurfaceItem *surfaceItem) override;
