@@ -24,7 +24,7 @@ public:
 
 private:
     // TODO: variadic template arguments for adding method arguments
-    template <typename T>
+    template<typename T>
     void forEachWindow(T method);
     bool m_initialized;
     Xcb::Window m_topOutline;
@@ -33,9 +33,8 @@ private:
     Xcb::Window m_leftOutline;
 };
 
-template <typename T>
-inline
-void NonCompositedOutlineVisual::forEachWindow(T method)
+template<typename T>
+inline void NonCompositedOutlineVisual::forEachWindow(T method)
 {
     (m_topOutline.*method)();
     (m_rightOutline.*method)();
