@@ -29,7 +29,7 @@ class X11WindowedQPainterOutput : public OutputLayer
 public:
     X11WindowedQPainterOutput(Output *output, xcb_window_t window);
 
-    OutputLayerBeginFrameInfo beginFrame() override;
+    std::optional<OutputLayerBeginFrameInfo> beginFrame() override;
     bool endFrame(const QRegion &renderedRegion, const QRegion &damagedRegion) override;
 
     xcb_window_t window;
