@@ -14,26 +14,27 @@
 #include "virtualdesktopmanageradaptor.h"
 
 // kwin
-#include "abstract_client.h"
 #include "atoms.h"
 #include "composite.h"
 #include "debug_console.h"
+#include "kwinadaptor.h"
 #include "main.h"
+#include "output.h"
 #include "placement.h"
 #include "platform.h"
 #include "pluginmanager.h"
-#include "kwinadaptor.h"
-#include "scene.h"
+#include "renderbackend.h"
 #include "unmanaged.h"
-#include "workspace.h"
 #include "virtualdesktops.h"
-#ifdef KWIN_BUILD_ACTIVITIES
+#include "window.h"
+#include "workspace.h"
+#if KWIN_BUILD_ACTIVITIES
 #include "activities.h"
 #endif
 
 // Qt
-#include <QOpenGLContext>
 #include <QDBusServiceWatcher>
+#include <QOpenGLContext>
 
 namespace KWin
 {
@@ -42,7 +43,7 @@ DBusInterface::DBusInterface(QObject *parent)
     : QObject(parent)
     , m_serviceName(QStringLiteral("org.kde.KWin"))
 {
-    (void) new KWinAdaptor(this);
+    (void)new KWinAdaptor(this);
 
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.registerObject(QStringLiteral("/KWin"), this);
@@ -92,11 +93,11 @@ void DBusInterface::announceService()
 }
 
 // wrap void methods with no arguments to Workspace
-#define WRAP(name) \
-void DBusInterface::name() \
-{\
-    Workspace::self()->name();\
-}
+#define WRAP(name)                 \
+    void DBusInterface::name()     \
+    {                              \
+        Workspace::self()->name(); \
+    }
 
 WRAP(reconfigure)
 
@@ -107,11 +108,11 @@ void DBusInterface::killWindow()
     Workspace::self()->slotKillWindow();
 }
 
-#define WRAP(name) \
-void DBusInterface::name() \
-{\
-    Placement::self()->name();\
-}
+#define WRAP(name)                 \
+    void DBusInterface::name()     \
+    {                              \
+        Placement::self()->name(); \
+    }
 
 WRAP(cascadeDesktop)
 WRAP(unclutterDesktop)
@@ -119,19 +120,24 @@ WRAP(unclutterDesktop)
 #undef WRAP
 
 // wrap returning methods with no arguments to Workspace
-#define WRAP( rettype, name ) \
-rettype DBusInterface::name( ) \
-{\
-    return Workspace::self()->name(); \
-}
+#define WRAP(rettype, name)               \
+    rettype DBusInterface::name()         \
+    {                                     \
+        return Workspace::self()->name(); \
+    }
 
 WRAP(QString, supportInformation)
 
 #undef WRAP
 
+QString DBusInterface::activeOutputName()
+{
+    return Workspace::self()->activeOutput()->name();
+}
+
 bool DBusInterface::startActivity(const QString &in0)
 {
-#ifdef KWIN_BUILD_ACTIVITIES
+#if KWIN_BUILD_ACTIVITIES
     if (!Activities::self()) {
         return false;
     }
@@ -144,7 +150,7 @@ bool DBusInterface::startActivity(const QString &in0)
 
 bool DBusInterface::stopActivity(const QString &in0)
 {
-#ifdef KWIN_BUILD_ACTIVITIES
+#if KWIN_BUILD_ACTIVITIES
     if (!Activities::self()) {
         return false;
     }
@@ -186,36 +192,38 @@ void DBusInterface::replace()
     QCoreApplication::exit(133);
 }
 
-namespace {
-QVariantMap clientToVariantMap(const AbstractClient *c)
+namespace
 {
-    return {
+QVariantMap clientToVariantMap(const Window *c)
+{
+    return
+    {
         {QStringLiteral("resourceClass"), c->resourceClass()},
-        {QStringLiteral("resourceName"), c->resourceName()},
-        {QStringLiteral("desktopFile"), c->desktopFileName()},
-        {QStringLiteral("role"), c->windowRole()},
-        {QStringLiteral("caption"), c->captionNormal()},
-        {QStringLiteral("clientMachine"), c->wmClientMachine(true)},
-        {QStringLiteral("localhost"), c->isLocalhost()},
-        {QStringLiteral("type"), c->windowType()},
-        {QStringLiteral("x"), c->x()},
-        {QStringLiteral("y"), c->y()},
-        {QStringLiteral("width"), c->width()},
-        {QStringLiteral("height"), c->height()},
-        {QStringLiteral("desktops"), c->desktopIds()},
-        {QStringLiteral("minimized"), c->isMinimized()},
-        {QStringLiteral("shaded"), c->isShade()},
-        {QStringLiteral("fullscreen"), c->isFullScreen()},
-        {QStringLiteral("keepAbove"), c->keepAbove()},
-        {QStringLiteral("keepBelow"), c->keepBelow()},
-        {QStringLiteral("noBorder"), c->noBorder()},
-        {QStringLiteral("skipTaskbar"), c->skipTaskbar()},
-        {QStringLiteral("skipPager"), c->skipPager()},
-        {QStringLiteral("skipSwitcher"), c->skipSwitcher()},
-        {QStringLiteral("maximizeHorizontal"), c->maximizeMode() & MaximizeHorizontal},
-        {QStringLiteral("maximizeVertical"), c->maximizeMode() & MaximizeVertical},
-#ifdef KWIN_BUILD_ACTIVITIES
-        {QStringLiteral("activities"), c->activities()},
+            {QStringLiteral("resourceName"), c->resourceName()},
+            {QStringLiteral("desktopFile"), c->desktopFileName()},
+            {QStringLiteral("role"), c->windowRole()},
+            {QStringLiteral("caption"), c->captionNormal()},
+            {QStringLiteral("clientMachine"), c->wmClientMachine(true)},
+            {QStringLiteral("localhost"), c->isLocalhost()},
+            {QStringLiteral("type"), c->windowType()},
+            {QStringLiteral("x"), c->x()},
+            {QStringLiteral("y"), c->y()},
+            {QStringLiteral("width"), c->width()},
+            {QStringLiteral("height"), c->height()},
+            {QStringLiteral("desktops"), c->desktopIds()},
+            {QStringLiteral("minimized"), c->isMinimized()},
+            {QStringLiteral("shaded"), c->isShade()},
+            {QStringLiteral("fullscreen"), c->isFullScreen()},
+            {QStringLiteral("keepAbove"), c->keepAbove()},
+            {QStringLiteral("keepBelow"), c->keepBelow()},
+            {QStringLiteral("noBorder"), c->noBorder()},
+            {QStringLiteral("skipTaskbar"), c->skipTaskbar()},
+            {QStringLiteral("skipPager"), c->skipPager()},
+            {QStringLiteral("skipSwitcher"), c->skipSwitcher()},
+            {QStringLiteral("maximizeHorizontal"), c->maximizeMode() & MaximizeHorizontal},
+            {QStringLiteral("maximizeVertical"), c->maximizeMode() & MaximizeVertical},
+#if KWIN_BUILD_ACTIVITIES
+            {QStringLiteral("activities"), c->activities()},
 #endif
     };
 }
@@ -226,27 +234,30 @@ QVariantMap DBusInterface::queryWindowInfo()
     m_replyQueryWindowInfo = message();
     setDelayedReply(true);
     kwinApp()->platform()->startInteractiveWindowSelection(
-        [this] (Toplevel *t) {
-            if (auto c = qobject_cast<AbstractClient*>(t)) {
-                QDBusConnection::sessionBus().send(m_replyQueryWindowInfo.createReply(clientToVariantMap(c)));
-            } else if (qobject_cast<Unmanaged*>(t)) {
-                QDBusConnection::sessionBus().send(m_replyQueryWindowInfo.createErrorReply(
-                    QStringLiteral("org.kde.KWin.Error.InvalidWindow"),
-                    QStringLiteral("Tried to query information about an unmanaged window")));
-            } else {
+        [this](Window *t) {
+            if (!t) {
                 QDBusConnection::sessionBus().send(m_replyQueryWindowInfo.createErrorReply(
                     QStringLiteral("org.kde.KWin.Error.UserCancel"),
                     QStringLiteral("User cancelled the query")));
+                return;
             }
-        }
-    );
+            if (t->isClient()) {
+                QDBusConnection::sessionBus().send(m_replyQueryWindowInfo.createReply(clientToVariantMap(t)));
+            } else {
+                QDBusConnection::sessionBus().send(m_replyQueryWindowInfo.createErrorReply(
+                    QStringLiteral("org.kde.KWin.Error.InvalidWindow"),
+                    QStringLiteral("Tried to query information about an unmanaged window")));
+            }
+        });
     return QVariantMap{};
 }
 
 QVariantMap DBusInterface::getWindowInfo(const QString &uuid)
 {
     const auto id = QUuid::fromString(uuid);
-    const auto client = workspace()->findAbstractClient([&id] (const AbstractClient *c) { return c->internalId() == id; });
+    const auto client = workspace()->findAbstractClient([&id](const Window *c) {
+        return c->internalId() == id;
+    });
     if (client) {
         return clientToVariantMap(client);
     } else {
@@ -273,10 +284,10 @@ QString CompositorDBusInterface::compositingNotPossibleReason() const
 
 QString CompositorDBusInterface::compositingType() const
 {
-    if (!m_compositor->scene()) {
+    if (!m_compositor->compositing()) {
         return QStringLiteral("none");
     }
-    switch (m_compositor->scene()->compositingType()) {
+    switch (m_compositor->backend()->compositingType()) {
     case OpenGLCompositing:
         if (QOpenGLContext::openGLModuleType() == QOpenGLContext::LibGLES) {
             return QStringLiteral("gles");
@@ -314,14 +325,14 @@ bool CompositorDBusInterface::platformRequiresCompositing() const
 void CompositorDBusInterface::resume()
 {
     if (kwinApp()->operationMode() == Application::OperationModeX11) {
-        static_cast<X11Compositor*>(m_compositor)->resume(X11Compositor::ScriptSuspend);
+        static_cast<X11Compositor *>(m_compositor)->resume(X11Compositor::ScriptSuspend);
     }
 }
 
 void CompositorDBusInterface::suspend()
 {
     if (kwinApp()->operationMode() == Application::OperationModeX11) {
-        static_cast<X11Compositor*>(m_compositor)->suspend(X11Compositor::ScriptSuspend);
+        static_cast<X11Compositor *>(m_compositor)->suspend(X11Compositor::ScriptSuspend);
     }
 }
 
@@ -347,9 +358,6 @@ QStringList CompositorDBusInterface::supportedOpenGLPlatformInterfaces() const
     return interfaces;
 }
 
-
-
-
 VirtualDesktopManagerDBusInterface::VirtualDesktopManagerDBusInterface(VirtualDesktopManager *parent)
     : QObject(parent)
     , m_manager(parent)
@@ -359,78 +367,59 @@ VirtualDesktopManagerDBusInterface::VirtualDesktopManagerDBusInterface(VirtualDe
 
     new VirtualDesktopManagerAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/VirtualDesktopManager"),
-        QStringLiteral("org.kde.KWin.VirtualDesktopManager"),
-        this
-    );
+                                                 QStringLiteral("org.kde.KWin.VirtualDesktopManager"),
+                                                 this);
 
-    connect(m_manager, &VirtualDesktopManager::currentChanged, this,
-        [this](uint previousDesktop, uint newDesktop) {
-            Q_UNUSED(previousDesktop);
-            Q_UNUSED(newDesktop);
-            Q_EMIT currentChanged(m_manager->currentDesktop()->id());
-        }
-    );
+    connect(m_manager, &VirtualDesktopManager::currentChanged, this, [this](uint previousDesktop, uint newDesktop) {
+        Q_UNUSED(previousDesktop);
+        Q_UNUSED(newDesktop);
+        Q_EMIT currentChanged(m_manager->currentDesktop()->id());
+    });
 
-    connect(m_manager, &VirtualDesktopManager::countChanged, this,
-        [this](uint previousCount, uint newCount) {
-            Q_UNUSED(previousCount);
-            Q_EMIT countChanged(newCount);
-            Q_EMIT desktopsChanged(desktops());
-        }
-    );
+    connect(m_manager, &VirtualDesktopManager::countChanged, this, [this](uint previousCount, uint newCount) {
+        Q_UNUSED(previousCount);
+        Q_EMIT countChanged(newCount);
+        Q_EMIT desktopsChanged(desktops());
+    });
 
-    connect(m_manager, &VirtualDesktopManager::navigationWrappingAroundChanged, this,
-        [this]() {
-            Q_EMIT navigationWrappingAroundChanged(isNavigationWrappingAround());
-        }
-    );
+    connect(m_manager, &VirtualDesktopManager::navigationWrappingAroundChanged, this, [this]() {
+        Q_EMIT navigationWrappingAroundChanged(isNavigationWrappingAround());
+    });
 
     connect(m_manager, &VirtualDesktopManager::rowsChanged, this, &VirtualDesktopManagerDBusInterface::rowsChanged);
 
     const QVector<VirtualDesktop *> allDesks = m_manager->desktops();
     for (auto *vd : allDesks) {
-        connect(vd, &VirtualDesktop::x11DesktopNumberChanged, this,
-            [this, vd]() {
-                DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
-                Q_EMIT desktopDataChanged(vd->id(), data);
-                Q_EMIT desktopsChanged(desktops());
-            }
-        );
-        connect(vd, &VirtualDesktop::nameChanged, this,
-            [this, vd]() {
-                DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
-                Q_EMIT desktopDataChanged(vd->id(), data);
-                Q_EMIT desktopsChanged(desktops());
-            }
-        );
-    }
-    connect(m_manager, &VirtualDesktopManager::desktopCreated, this,
-        [this](VirtualDesktop *vd) {
-            connect(vd, &VirtualDesktop::x11DesktopNumberChanged, this,
-                [this, vd]() {
-                    DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
-                    Q_EMIT desktopDataChanged(vd->id(), data);
-                    Q_EMIT desktopsChanged(desktops());
-                }
-            );
-            connect(vd, &VirtualDesktop::nameChanged, this,
-                [this, vd]() {
-                    DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
-                    Q_EMIT desktopDataChanged(vd->id(), data);
-                    Q_EMIT desktopsChanged(desktops());
-                }
-            );
+        connect(vd, &VirtualDesktop::x11DesktopNumberChanged, this, [this, vd]() {
             DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
-            Q_EMIT desktopCreated(vd->id(), data);
+            Q_EMIT desktopDataChanged(vd->id(), data);
             Q_EMIT desktopsChanged(desktops());
-        }
-    );
-    connect(m_manager, &VirtualDesktopManager::desktopRemoved, this,
-        [this](VirtualDesktop *vd) {
-            Q_EMIT desktopRemoved(vd->id());
+        });
+        connect(vd, &VirtualDesktop::nameChanged, this, [this, vd]() {
+            DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
+            Q_EMIT desktopDataChanged(vd->id(), data);
             Q_EMIT desktopsChanged(desktops());
-        }
-    );
+        });
+    }
+    connect(m_manager, &VirtualDesktopManager::desktopCreated, this, [this](VirtualDesktop *vd) {
+        connect(vd, &VirtualDesktop::x11DesktopNumberChanged, this, [this, vd]() {
+            DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
+            Q_EMIT desktopDataChanged(vd->id(), data);
+            Q_EMIT desktopsChanged(desktops());
+        });
+        connect(vd, &VirtualDesktop::nameChanged, this, [this, vd]() {
+            DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
+            Q_EMIT desktopDataChanged(vd->id(), data);
+            Q_EMIT desktopsChanged(desktops());
+        });
+        DBusDesktopDataStruct data{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
+        Q_EMIT desktopCreated(vd->id(), data);
+        Q_EMIT desktopsChanged(desktops());
+    });
+    connect(m_manager, &VirtualDesktopManager::desktopRemoved, this, [this](VirtualDesktop *vd) {
+        Q_EMIT desktopRemoved(vd->id());
+        Q_EMIT desktopsChanged(desktops());
+    });
 }
 
 uint VirtualDesktopManagerDBusInterface::count() const
@@ -491,11 +480,10 @@ DBusDesktopDataVector VirtualDesktopManagerDBusInterface::desktops() const
     desktopVect.reserve(m_manager->count());
 
     std::transform(desks.constBegin(), desks.constEnd(),
-        std::back_inserter(desktopVect),
-        [] (const VirtualDesktop *vd) {
-            return DBusDesktopDataStruct{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
-        }
-    );
+                   std::back_inserter(desktopVect),
+                   [](const VirtualDesktop *vd) {
+                       return DBusDesktopDataStruct{.position = vd->x11DesktopNumber() - 1, .id = vd->id(), .name = vd->name()};
+                   });
 
     return desktopVect;
 }
