@@ -12,11 +12,14 @@
 #include <kwinglplatform.h>
 #include <kwinglutils.h>
 
-#include <QVector>
-#include <QVector2D>
 #include <QStack>
+#include <QVector2D>
+#include <QVector>
 
-#include <KWaylandServer/blur_interface.h>
+namespace KWaylandServer
+{
+class BlurManagerInterface;
+}
 
 namespace KWin
 {
@@ -38,14 +41,14 @@ public:
 
     void reconfigure(ReconfigureFlags flags) override;
     void prePaintScreen(ScreenPrePaintData &data, std::chrono::milliseconds presentTime) override;
-    void prePaintWindow(EffectWindow* w, WindowPrePaintData& data, std::chrono::milliseconds presentTime) override;
+    void prePaintWindow(EffectWindow *w, WindowPrePaintData &data, std::chrono::milliseconds presentTime) override;
     void drawWindow(EffectWindow *w, int mask, const QRegion &region, WindowPaintData &data) override;
-    void paintEffectFrame(EffectFrame *frame, const QRegion &region, double opacity, double frameOpacity) override;
 
     bool provides(Feature feature) override;
     bool isActive() const override;
 
-    int requestedEffectChainPosition() const override {
+    int requestedEffectChainPosition() const override
+    {
         return 75;
     }
 
@@ -58,6 +61,7 @@ public Q_SLOTS:
     void slotWindowDeleted(KWin::EffectWindow *w);
     void slotPropertyNotify(KWin::EffectWindow *w, long atom);
     void slotScreenGeometryChanged();
+    void setupDecorationConnections(EffectWindow *w);
 
 private:
     QRect expand(const QRect &rect) const;
@@ -67,6 +71,8 @@ private:
     void initBlurStrengthValues();
     void updateTexture();
     QRegion blurRegion(const EffectWindow *w) const;
+    QRegion decorationBlurRegion(const EffectWindow *w) const;
+    bool decorationSupportsBlurBehind(const EffectWindow *w) const;
     bool shouldBlur(const EffectWindow *w, int mask, const WindowPaintData &data) const;
     void updateBlurRegion(EffectWindow *w) const;
     void doBlur(const QRegion &shape, const QRect &screen, const float opacity, const QMatrix4x4 &screenProjection, bool isDock, QRect windowRect);
@@ -82,9 +88,9 @@ private:
 
 private:
     BlurShader *m_shader;
-    QVector <GLRenderTarget*> m_renderTargets;
-    QVector <GLTexture> m_renderTextures;
-    QStack <GLRenderTarget*> m_renderTargetStack;
+    QVector<GLFramebuffer *> m_renderTargets;
+    QVector<GLTexture *> m_renderTextures;
+    QStack<GLFramebuffer *> m_renderTargetStack;
 
     QScopedPointer<GLTexture> m_noiseTexture;
 
@@ -99,29 +105,30 @@ private:
     int m_noiseStrength;
     int m_scalingFactor;
 
-    struct OffsetStruct {
+    struct OffsetStruct
+    {
         float minOffset;
         float maxOffset;
         int expandSize;
     };
 
-    QVector <OffsetStruct> blurOffsets;
+    QVector<OffsetStruct> blurOffsets;
 
-    struct BlurValuesStruct {
+    struct BlurValuesStruct
+    {
         int iteration;
         float offset;
     };
 
-    QVector <BlurValuesStruct> blurStrengthValues;
+    QVector<BlurValuesStruct> blurStrengthValues;
 
-    QMap <EffectWindow*, QMetaObject::Connection> windowBlurChangedConnections;
+    QMap<EffectWindow *, QMetaObject::Connection> windowBlurChangedConnections;
 
     static KWaylandServer::BlurManagerInterface *s_blurManager;
     static QTimer *s_blurManagerRemoveTimer;
 };
 
-inline
-bool BlurEffect::provides(Effect::Feature feature)
+inline bool BlurEffect::provides(Effect::Feature feature)
 {
     if (feature == Blur) {
         return true;
@@ -129,8 +136,6 @@ bool BlurEffect::provides(Effect::Feature feature)
     return KWin::Effect::provides(feature);
 }
 
-
 } // namespace KWin
 
 #endif
-
