@@ -20,8 +20,8 @@
 #include <QTimer>
 // KDE
 #include <KConfigGroup>
-#include <KSharedConfig>
 #include <KSelectionOwner>
+#include <KSharedConfig>
 #include <KWindowSystem>
 // KWin
 #include <kwinglutils.h>
@@ -52,22 +52,17 @@ static const int BLINKING_FRAMES = 5;
 static const int BLINKING_FRAME_DURATION = 100;
 // duration of one blinking animation
 static const int BLINKING_DURATION = BLINKING_FRAME_DURATION * BLINKING_FRAMES;
-//const int color_to_pixmap[] = { 0, 1, 2, 3, 2, 1 };
+// const int color_to_pixmap[] = { 0, 1, 2, 3, 2, 1 };
 static const int FRAME_TO_BOUNCE_YOFFSET[] = {
-    -5, -1, 2, 5, 8, 10, 12, 13, 15, 15, 15, 15, 14, 12, 10, 8, 5, 2, -1, -5
-};
+    -5, -1, 2, 5, 8, 10, 12, 13, 15, 15, 15, 15, 14, 12, 10, 8, 5, 2, -1, -5};
 static const QSize BOUNCE_SIZES[] = {
-    QSize(16, 16), QSize(14, 18), QSize(12, 20), QSize(18, 14), QSize(20, 12)
-};
+    QSize(16, 16), QSize(14, 18), QSize(12, 20), QSize(18, 14), QSize(20, 12)};
 static const int FRAME_TO_BOUNCE_TEXTURE[] = {
-    0, 0, 0, 1, 2, 2, 1, 0, 3, 4, 4, 3, 0, 1, 2, 2, 1, 0, 0, 0
-};
+    0, 0, 0, 1, 2, 2, 1, 0, 3, 4, 4, 3, 0, 1, 2, 2, 1, 0, 0, 0};
 static const int FRAME_TO_BLINKING_COLOR[] = {
-    0, 1, 2, 3, 2, 1
-};
+    0, 1, 2, 3, 2, 1};
 static const QColor BLINKING_COLORS[] = {
-    Qt::black, Qt::darkGray, Qt::lightGray, Qt::white, Qt::white
-};
+    Qt::black, Qt::darkGray, Qt::lightGray, Qt::white, Qt::white};
 static const int s_startupDefaultTimeout = 5;
 
 StartupFeedbackEffect::StartupFeedbackEffect()
@@ -146,11 +141,11 @@ void StartupFeedbackEffect::reconfigure(Effect::ReconfigureFlags flags)
     m_startupInfo->setTimeout(m_timeout.count());
     const bool busyBlinking = c.readEntry("Blinking", false);
     const bool busyBouncing = c.readEntry("Bouncing", true);
-    if (!busyCursor)
+    if (!busyCursor) {
         m_type = NoFeedback;
-    else if (busyBouncing)
+    } else if (busyBouncing) {
         m_type = BouncingFeedback;
-    else if (busyBlinking) {
+    } else if (busyBlinking) {
         m_type = BlinkingFeedback;
         if (effects->compositingType() == OpenGLCompositing) {
             ensureResources();
@@ -161,15 +156,16 @@ void StartupFeedbackEffect::reconfigure(Effect::ReconfigureFlags flags)
                 qCDebug(KWIN_STARTUPFEEDBACK) << "Blinking Shader is not valid";
             }
         }
-    } else
+    } else {
         m_type = PassiveFeedback;
+    }
     if (m_active) {
         stop();
         start(m_startups[m_currentStartup]);
     }
 }
 
-void StartupFeedbackEffect::prePaintScreen(ScreenPrePaintData& data, std::chrono::milliseconds presentTime)
+void StartupFeedbackEffect::prePaintScreen(ScreenPrePaintData &data, std::chrono::milliseconds presentTime)
 {
     int time = 0;
     if (m_lastPresentTime.count()) {
@@ -182,7 +178,7 @@ void StartupFeedbackEffect::prePaintScreen(ScreenPrePaintData& data, std::chrono
     }
     if (m_active) {
         // need the unclipped version
-        switch(m_type) {
+        switch (m_type) {
         case BouncingFeedback:
             m_progress = (m_progress + time) % BOUNCE_DURATION;
             m_frame = qRound((qreal)m_progress / (qreal)BOUNCE_FRAME_DURATION) % BOUNCE_FRAMES;
@@ -200,14 +196,14 @@ void StartupFeedbackEffect::prePaintScreen(ScreenPrePaintData& data, std::chrono
     effects->prePaintScreen(data, presentTime);
 }
 
-void StartupFeedbackEffect::paintScreen(int mask, const QRegion &region, ScreenPaintData& data)
+void StartupFeedbackEffect::paintScreen(int mask, const QRegion &region, ScreenPaintData &data)
 {
     effects->paintScreen(mask, region, data);
     if (m_active) {
-        GLTexture* texture;
-        switch(m_type) {
+        GLTexture *texture;
+        switch (m_type) {
         case BouncingFeedback:
-            texture = m_bouncingTextures[ FRAME_TO_BOUNCE_TEXTURE[ m_frame ]].get();
+            texture = m_bouncingTextures[FRAME_TO_BOUNCE_TEXTURE[m_frame]].get();
             break;
         case BlinkingFeedback: // fall through
         case PassiveFeedback:
@@ -220,7 +216,7 @@ void StartupFeedbackEffect::paintScreen(int mask, const QRegion &region, ScreenP
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         texture->bind();
         if (m_type == BlinkingFeedback && m_blinkingShader && m_blinkingShader->isValid()) {
-            const QColor& blinkingColor = BLINKING_COLORS[ FRAME_TO_BLINKING_COLOR[ m_frame ]];
+            const QColor &blinkingColor = BLINKING_COLORS[FRAME_TO_BLINKING_COLOR[m_frame]];
             ShaderManager::instance()->pushShader(m_blinkingShader.get());
             m_blinkingShader->setUniform(GLShader::Color, blinkingColor);
         } else {
@@ -229,7 +225,7 @@ void StartupFeedbackEffect::paintScreen(int mask, const QRegion &region, ScreenP
         QMatrix4x4 mvp = data.projectionMatrix();
         mvp.translate(m_currentGeometry.x(), m_currentGeometry.y());
         ShaderManager::instance()->getBoundShader()->setUniform(GLShader::ModelViewProjectionMatrix, mvp);
-        texture->render(m_currentGeometry, m_currentGeometry);
+        texture->render(m_currentGeometry);
         ShaderManager::instance()->popShader();
         texture->unbind();
         glDisable(GL_BLEND);
@@ -240,14 +236,15 @@ void StartupFeedbackEffect::postPaintScreen()
 {
     if (m_active) {
         m_dirtyRect = m_currentGeometry; // ensure the now dirty region is cleaned on the next pass
-        if (m_type == BlinkingFeedback || m_type == BouncingFeedback)
+        if (m_type == BlinkingFeedback || m_type == BouncingFeedback) {
             effects->addRepaint(m_dirtyRect); // we also have to trigger a repaint
+        }
     }
     effects->postPaintScreen();
 }
 
-void StartupFeedbackEffect::slotMouseChanged(const QPoint& pos, const QPoint& oldpos, Qt::MouseButtons buttons,
-        Qt::MouseButtons oldbuttons, Qt::KeyboardModifiers modifiers, Qt::KeyboardModifiers oldmodifiers)
+void StartupFeedbackEffect::slotMouseChanged(const QPoint &pos, const QPoint &oldpos, Qt::MouseButtons buttons,
+                                             Qt::MouseButtons oldbuttons, Qt::KeyboardModifiers modifiers, Qt::KeyboardModifiers oldmodifiers)
 {
     Q_UNUSED(pos)
     Q_UNUSED(oldpos)
@@ -289,7 +286,7 @@ void StartupFeedbackEffect::gotRemoveStartup(const QString &id)
         return;
     }
     m_currentStartup = m_startups.begin().key();
-    start(m_startups[ m_currentStartup ]);
+    start(m_startups[m_currentStartup]);
 }
 
 void StartupFeedbackEffect::gotStartupChange(const QString &id, const QIcon &icon)
@@ -305,10 +302,12 @@ void StartupFeedbackEffect::gotStartupChange(const QString &id, const QIcon &ico
 
 void StartupFeedbackEffect::start(const Startup &startup)
 {
-    if (m_type == NoFeedback || m_splashVisible || effects->isCursorHidden())
+    if (m_type == NoFeedback || m_splashVisible || effects->isCursorHidden()) {
         return;
-    if (!m_active)
+    }
+    if (!m_active) {
         effects->startMousePolling();
+    }
     m_active = true;
 
     // read details about the mouse-cursor theme define per default
@@ -320,8 +319,9 @@ void StartupFeedbackEffect::start(const Startup &startup)
         iconSize = QApplication::style()->pixelMetric(QStyle::PM_SmallIconSize);
     }
     // get ratio for bouncing cursor so we don't need to manually calculate the sizes for each icon size
-    if (m_type == BouncingFeedback)
+    if (m_type == BouncingFeedback) {
         m_bounceSizesRatio = iconSize / 16.0;
+    }
     const QPixmap iconPixmap = startup.icon.pixmap(iconSize);
     prepareTextures(iconPixmap);
     m_dirtyRect = m_currentGeometry = feedbackRect();
@@ -330,12 +330,13 @@ void StartupFeedbackEffect::start(const Startup &startup)
 
 void StartupFeedbackEffect::stop()
 {
-    if (m_active)
+    if (m_active) {
         effects->stopMousePolling();
+    }
     m_active = false;
     m_lastPresentTime = std::chrono::milliseconds::zero();
     effects->makeOpenGLContextCurrent();
-    switch(m_type) {
+    switch (m_type) {
     case BouncingFeedback:
         for (int i = 0; i < 5; ++i) {
             m_bouncingTextures[i].reset();
@@ -353,10 +354,10 @@ void StartupFeedbackEffect::stop()
     effects->addRepaintFull();
 }
 
-void StartupFeedbackEffect::prepareTextures(const QPixmap& pix)
+void StartupFeedbackEffect::prepareTextures(const QPixmap &pix)
 {
     effects->makeOpenGLContextCurrent();
-    switch(m_type) {
+    switch (m_type) {
     case BouncingFeedback:
         for (int i = 0; i < 5; ++i) {
             m_bouncingTextures[i].reset(new GLTexture(scalePixmap(pix, BOUNCE_SIZES[i])));
@@ -378,39 +379,41 @@ void StartupFeedbackEffect::prepareTextures(const QPixmap& pix)
     }
 }
 
-QImage StartupFeedbackEffect::scalePixmap(const QPixmap& pm, const QSize& size) const
+QImage StartupFeedbackEffect::scalePixmap(const QPixmap &pm, const QSize &size) const
 {
-    const QSize& adjustedSize = size * m_bounceSizesRatio;
+    const QSize &adjustedSize = size * m_bounceSizesRatio;
     QImage scaled = pm.toImage().scaled(adjustedSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-    if (scaled.format() != QImage::Format_ARGB32_Premultiplied && scaled.format() != QImage::Format_ARGB32)
+    if (scaled.format() != QImage::Format_ARGB32_Premultiplied && scaled.format() != QImage::Format_ARGB32) {
         scaled = scaled.convertToFormat(QImage::Format_ARGB32);
+    }
 
     QImage result(20 * m_bounceSizesRatio, 20 * m_bounceSizesRatio, QImage::Format_ARGB32);
     QPainter p(&result);
     p.setCompositionMode(QPainter::CompositionMode_Source);
     p.fillRect(result.rect(), Qt::transparent);
-    p.drawImage((20 * m_bounceSizesRatio - adjustedSize.width()) / 2, (20*m_bounceSizesRatio - adjustedSize.height()) / 2, scaled, 0, 0, adjustedSize.width(), adjustedSize.height() * m_bounceSizesRatio);
+    p.drawImage((20 * m_bounceSizesRatio - adjustedSize.width()) / 2, (20 * m_bounceSizesRatio - adjustedSize.height()) / 2, scaled, 0, 0, adjustedSize.width(), adjustedSize.height() * m_bounceSizesRatio);
     return result;
 }
 
 QRect StartupFeedbackEffect::feedbackRect() const
 {
     int xDiff;
-    if (m_cursorSize <= 16)
+    if (m_cursorSize <= 16) {
         xDiff = 8 + 7;
-    else if (m_cursorSize <= 32)
+    } else if (m_cursorSize <= 32) {
         xDiff = 16 + 7;
-    else if (m_cursorSize <= 48)
+    } else if (m_cursorSize <= 48) {
         xDiff = 24 + 7;
-    else
+    } else {
         xDiff = 32 + 7;
+    }
     int yDiff = xDiff;
-    GLTexture* texture = nullptr;
+    GLTexture *texture = nullptr;
     int yOffset = 0;
-    switch(m_type) {
+    switch (m_type) {
     case BouncingFeedback:
-        texture = m_bouncingTextures[ FRAME_TO_BOUNCE_TEXTURE[ m_frame ]].get();
-        yOffset = FRAME_TO_BOUNCE_YOFFSET[ m_frame ] * m_bounceSizesRatio;
+        texture = m_bouncingTextures[FRAME_TO_BOUNCE_TEXTURE[m_frame]].get();
+        yOffset = FRAME_TO_BOUNCE_YOFFSET[m_frame] * m_bounceSizesRatio;
         break;
     case BlinkingFeedback: // fall through
     case PassiveFeedback:
@@ -422,8 +425,9 @@ QRect StartupFeedbackEffect::feedbackRect() const
     }
     const QPoint cursorPos = effects->cursorPos() + QPoint(xDiff, yDiff + yOffset);
     QRect rect;
-    if( texture )
-       rect = QRect(cursorPos, texture->size());
+    if (texture) {
+        rect = QRect(cursorPos, texture->size());
+    }
     return rect;
 }
 
