@@ -15,6 +15,7 @@
 #include "nightcolorsettings.h"
 #include "suncalc.h"
 
+#include <input.h>
 #include <main.h>
 #include <platform.h>
 #include <session.h>
@@ -27,7 +28,8 @@
 #include <QDBusConnection>
 #include <QTimer>
 
-namespace KWin {
+namespace KWin
+{
 
 static const int QUICK_ADJUST_DURATION = 2000;
 static const int TEMPERATURE_STEP = 50;
@@ -67,7 +69,7 @@ NightColorManager::NightColorManager(QObject *parent)
             QStringLiteral("/org/kde/osdService"),
             QStringLiteral("org.kde.osdService"),
             QStringLiteral("showText"));
-        message.setArguments({ iconName, text });
+        message.setArguments({iconName, text});
 
         QDBusConnection::sessionBus().asyncCall(message);
     });
@@ -302,20 +304,14 @@ void NightColorManager::readConfig()
     QTime mrB = QTime::fromString(s->morningBeginFixed(), "hhmm");
     QTime evB = QTime::fromString(s->eveningBeginFixed(), "hhmm");
 
-    int diffME = mrB.msecsTo(evB);
-    if (diffME <= 0) {
-        // morning not strictly before evening - use defaults
-        mrB = QTime(6,0);
-        evB = QTime(18,0);
-        diffME = mrB.msecsTo(evB);
-    }
+    int diffME = evB > mrB ? mrB.msecsTo(evB) : evB.msecsTo(mrB);
     int diffMin = qMin(diffME, MSC_DAY - diffME);
 
     int trTime = s->transitionTime() * 1000 * 60;
     if (trTime < 0 || diffMin <= trTime) {
         // transition time too long - use defaults
-        mrB = QTime(6,0);
-        evB = QTime(18,0);
+        mrB = QTime(6, 0);
+        evB = QTime(18, 0);
         trTime = FALLBACK_SLOW_UPDATE_TIME;
     }
     m_morning = mrB;
@@ -329,7 +325,9 @@ void NightColorManager::resetAllTimers()
     if (isAvailable()) {
         setRunning(isEnabled() && !isInhibited());
         // we do this also for active being false in order to reset the temperature back to the day value
-        resetQuickAdjustTimer();
+        updateTransitionTimings(false);
+        updateTargetTemperature();
+        resetQuickAdjustTimer(currentTargetTemp());
     } else {
         setRunning(false);
     }
@@ -346,20 +344,19 @@ void NightColorManager::cancelAllTimers()
     m_quickAdjustTimer = nullptr;
 }
 
-void NightColorManager::resetQuickAdjustTimer()
+void NightColorManager::resetQuickAdjustTimer(int targetTemp)
 {
-    updateTransitionTimings(false);
-    updateTargetTemperature();
-
-    int tempDiff = qAbs(currentTargetTemp() - m_currentTemp);
+    int tempDiff = qAbs(targetTemp - m_currentTemp);
     // allow tolerance of one TEMPERATURE_STEP to compensate if a slow update is coincidental
     if (tempDiff > TEMPERATURE_STEP) {
         cancelAllTimers();
         m_quickAdjustTimer = new QTimer(this);
         m_quickAdjustTimer->setSingleShot(false);
-        connect(m_quickAdjustTimer, &QTimer::timeout, this, &NightColorManager::quickAdjust);
+        connect(m_quickAdjustTimer, &QTimer::timeout, this, [this, targetTemp]() {
+            quickAdjust(targetTemp);
+        });
 
-        int interval = QUICK_ADJUST_DURATION / (tempDiff / TEMPERATURE_STEP);
+        int interval = (QUICK_ADJUST_DURATION / (m_previewTimer && m_previewTimer->isActive() ? 8 : 1)) / (tempDiff / TEMPERATURE_STEP);
         if (interval == 0) {
             interval = 1;
         }
@@ -369,14 +366,13 @@ void NightColorManager::resetQuickAdjustTimer()
     }
 }
 
-void NightColorManager::quickAdjust()
+void NightColorManager::quickAdjust(int targetTemp)
 {
     if (!m_quickAdjustTimer) {
         return;
     }
 
     int nextTemp;
-    const int targetTemp = currentTargetTemp();
 
     if (m_currentTemp < targetTemp) {
         nextTemp = qMin(m_currentTemp + TEMPERATURE_STEP, targetTemp);
@@ -448,9 +444,13 @@ void NightColorManager::resetSlowUpdateTimer()
         m_slowUpdateTimer = new QTimer(this);
         m_slowUpdateTimer->setSingleShot(false);
         if (isDay) {
-            connect(m_slowUpdateTimer, &QTimer::timeout, this, [this]() {slowUpdate(m_dayTargetTemp);});
+            connect(m_slowUpdateTimer, &QTimer::timeout, this, [this]() {
+                slowUpdate(m_dayTargetTemp);
+            });
         } else {
-            connect(m_slowUpdateTimer, &QTimer::timeout, this, [this]() {slowUpdate(m_nightTargetTemp);});
+            connect(m_slowUpdateTimer, &QTimer::timeout, this, [this]() {
+                slowUpdate(m_nightTargetTemp);
+            });
         }
 
         // calculate interval such as temperature is changed by TEMPERATURE_STEP K per timer timeout
@@ -481,6 +481,28 @@ void NightColorManager::slowUpdate(int targetTemp)
     }
 }
 
+void NightColorManager::preview(uint previewTemp)
+{
+    resetQuickAdjustTimer((int)previewTemp);
+    if (m_previewTimer) {
+        delete m_previewTimer;
+        m_previewTimer = nullptr;
+    }
+    m_previewTimer = new QTimer(this);
+    m_previewTimer->setSingleShot(true);
+    connect(m_previewTimer, &QTimer::timeout, this, &NightColorManager::stopPreview);
+    m_previewTimer->start(15000);
+}
+
+void NightColorManager::stopPreview()
+{
+    if (m_previewTimer && m_previewTimer->isActive()) {
+        updateTransitionTimings(false);
+        updateTargetTemperature();
+        resetQuickAdjustTimer(currentTargetTemp());
+    }
+}
+
 void NightColorManager::updateTargetTemperature()
 {
     const int targetTemperature = mode() != NightColorMode::Constant && daylight() ? m_dayTargetTemp : m_nightTargetTemp;
@@ -507,20 +529,19 @@ void NightColorManager::updateTransitionTimings(bool force)
     const QDateTime todayNow = QDateTime::currentDateTime();
 
     if (m_mode == NightColorMode::Timings) {
-        const QDateTime morB = QDateTime(todayNow.date(), m_morning);
-        const QDateTime morE = morB.addSecs(m_trTime * 60);
-        const QDateTime eveB = QDateTime(todayNow.date(), m_evening);
-        const QDateTime eveE = eveB.addSecs(m_trTime * 60);
+        const QDateTime nextMorB = QDateTime(todayNow.date().addDays(m_morning < todayNow.time()), m_morning);
+        const QDateTime nextMorE = nextMorB.addSecs(m_trTime * 60);
+        const QDateTime nextEveB = QDateTime(todayNow.date().addDays(m_evening < todayNow.time()), m_evening);
+        const QDateTime nextEveE = nextEveB.addSecs(m_trTime * 60);
 
-        if (morB <= todayNow && todayNow < eveB) {
-            m_next = DateTimes(eveB, eveE);
-            m_prev = DateTimes(morB, morE);
-        } else if (todayNow < morB) {
-            m_next = DateTimes(morB, morE);
-            m_prev = DateTimes(eveB.addDays(-1), eveE.addDays(-1));
+        if (nextEveB < nextMorB) {
+            m_daylight = true;
+            m_next = DateTimes(nextEveB, nextEveE);
+            m_prev = DateTimes(nextMorB.addDays(-1), nextMorE.addDays(-1));
         } else {
-            m_next = DateTimes(morB.addDays(1), morE.addDays(1));
-            m_prev = DateTimes(eveB, eveE);
+            m_daylight = false;
+            m_next = DateTimes(nextMorB, nextMorE);
+            m_prev = DateTimes(nextEveB.addDays(-1), nextEveE.addDays(-1));
         }
         Q_EMIT previousTransitionTimingsChanged();
         Q_EMIT scheduledTransitionTimingsChanged();
@@ -538,14 +559,16 @@ void NightColorManager::updateTransitionTimings(bool force)
 
     if (!force) {
         // first try by only switching the timings
-        if (daylight()) {
-            // next is morning
-            m_prev = m_next;
-            m_next = getSunTimings(todayNow.addDays(1), lat, lng, true);
-        } else {
+        if (m_prev.first.date() == m_next.first.date()) {
             // next is evening
+            m_daylight = true;
             m_prev = m_next;
             m_next = getSunTimings(todayNow, lat, lng, false);
+        } else {
+            // next is morning
+            m_daylight = false;
+            m_prev = m_next;
+            m_next = getSunTimings(todayNow.addDays(1), lat, lng, true);
         }
     }
 
@@ -553,14 +576,17 @@ void NightColorManager::updateTransitionTimings(bool force)
         // in case this fails, reset them
         DateTimes morning = getSunTimings(todayNow, lat, lng, true);
         if (todayNow < morning.first) {
+            m_daylight = false;
             m_prev = getSunTimings(todayNow.addDays(-1), lat, lng, false);
             m_next = morning;
         } else {
             DateTimes evening = getSunTimings(todayNow, lat, lng, false);
             if (todayNow < evening.first) {
+                m_daylight = true;
                 m_prev = morning;
                 m_next = evening;
             } else {
+                m_daylight = false;
                 m_prev = evening;
                 m_next = getSunTimings(todayNow.addDays(1), lat, lng, true);
             }
@@ -581,16 +607,16 @@ DateTimes NightColorManager::getSunTimings(const QDateTime &dateTime, double lat
     const bool endDefined = !dateTimes.second.isNull();
     if (!beginDefined || !endDefined) {
         if (beginDefined) {
-            dateTimes.second = dateTimes.first.addMSecs( FALLBACK_SLOW_UPDATE_TIME );
+            dateTimes.second = dateTimes.first.addMSecs(FALLBACK_SLOW_UPDATE_TIME);
         } else if (endDefined) {
-            dateTimes.first = dateTimes.second.addMSecs( - FALLBACK_SLOW_UPDATE_TIME );
+            dateTimes.first = dateTimes.second.addMSecs(-FALLBACK_SLOW_UPDATE_TIME);
         } else {
             // Just use default values for morning and evening, but the user
             // will probably deactivate Night Color anyway if he is living
             // in a region without clear sun rise and set.
             const QTime referenceTime = morning ? QTime(6, 0) : QTime(18, 0);
             dateTimes.first = QDateTime(dateTime.date(), referenceTime);
-            dateTimes.second = dateTimes.first.addMSecs( FALLBACK_SLOW_UPDATE_TIME );
+            dateTimes.second = dateTimes.first.addMSecs(FALLBACK_SLOW_UPDATE_TIME);
         }
     }
     return dateTimes;
@@ -598,18 +624,16 @@ DateTimes NightColorManager::getSunTimings(const QDateTime &dateTime, double lat
 
 bool NightColorManager::checkAutomaticSunTimings() const
 {
-    if (m_prev.first.isValid() && m_prev.second.isValid() &&
-            m_next.first.isValid() && m_next.second.isValid()) {
+    if (m_prev.first.isValid() && m_prev.second.isValid() && m_next.first.isValid() && m_next.second.isValid()) {
         const QDateTime todayNow = QDateTime::currentDateTime();
-        return m_prev.first <= todayNow && todayNow < m_next.first &&
-                m_prev.first.msecsTo(m_next.first) < MSC_DAY * 23./24;
+        return m_prev.first <= todayNow && todayNow < m_next.first && m_prev.first.msecsTo(m_next.first) < MSC_DAY * 23. / 24;
     }
     return false;
 }
 
 bool NightColorManager::daylight() const
 {
-    return m_prev.first.date() == m_next.first.date();
+    return m_daylight;
 }
 
 int NightColorManager::currentTargetTemp() const
@@ -619,7 +643,7 @@ int NightColorManager::currentTargetTemp() const
     }
 
     if (m_mode == NightColorMode::Constant) {
-       return m_nightTargetTemp;
+        return m_nightTargetTemp;
     }
 
     const QDateTime todayNow = QDateTime::currentDateTime();
