@@ -118,10 +118,10 @@ void EGLPlatformContext::swapBuffers(QPlatformSurface *surface)
         if (!internalWindow) {
             return;
         }
-        context()->makeCurrent(surface->surface());
         glFlush();
-        internalWindow->present(window->swapFBO());
+        auto fbo = window->swapFBO();
         window->bindContentFBO();
+        internalWindow->present(fbo);
     }
 }
 
