@@ -7,6 +7,7 @@
 #pragma once
 
 #include "kwinglobals.h"
+#include "options.h"
 
 #include <QObject>
 
@@ -109,6 +110,22 @@ public:
      */
     void setVrrPolicy(VrrPolicy vrrPolicy);
 
+    /**
+     * Returns the latency policy for this render loop.
+     */
+    LatencyPolicy latencyPolicy() const;
+
+    /**
+     * Sets the latecy policy of this render loop to @a policy. By default,
+     * the latency policy of this render loop matches options->latencyPolicy().
+     */
+    void setLatencyPolicy(LatencyPolicy policy);
+
+    /**
+     * Resets the latency policy to the default value.
+     */
+    void resetLatencyPolicy();
+
 Q_SIGNALS:
     /**
      * This signal is emitted when the refresh rate of this RenderLoop has changed.
