@@ -22,7 +22,7 @@ class KWIN_EXPORT SurfaceItemX11 : public SurfaceItem
     Q_OBJECT
 
 public:
-    explicit SurfaceItemX11(Toplevel *window, Item *parent = nullptr);
+    explicit SurfaceItemX11(Window *window, Item *parent = nullptr);
     ~SurfaceItemX11() override;
 
     void preprocess() override;
@@ -36,7 +36,8 @@ public:
     QRegion opaque() const override;
 
 private Q_SLOTS:
-    void handleBufferGeometryChanged(Toplevel *toplevel, const QRect &old);
+    void handleBufferGeometryChanged(Window *window, const QRect &old);
+    void handleGeometryShapeChanged();
 
 protected:
     SurfacePixmap *createPixmap() override;
